| Title: | FABLE project data |
|---|---|
| Description: | Tool for easy downloading, cleaning, and sorting foodcrop Data downloaded from UPAg - Unified Portal for Agricultural Statistics by Department of Agriculture & Farmers Welfare. |
| Authors: | Ankit Saha [aut, cre], Anastasis Giannousakis [aut] |
| Maintainer: | Ankit Saha <[email protected]> |
| License: | LGPL-3 | file LICENSE |
| Version: | 1.7.2 |
| Built: | 2026-06-02 15:04:53 UTC |
| Source: | https://github.com/pik-piam/mrfable |
Provides functions to read in FABLE project data for India from here: https://eands.dacnet.nic.in/APY_96_To_07.htm
Anastasis Giannousakis
calcIndiaFoodcrop Calculates foodcrops data for India taken from here: https://eands.dacnet.nic.in/APY_96_To_07.htm
calcIndiaFoodcrop(subtype = "Area")calcIndiaFoodcrop(subtype = "Area")
subtype |
Area, Yield, or Production |
magpie object containing Area, Yield, and Production data.
Anastasis Giannousakis
## Not run: a <- madrat::calcOutput("IndiaFoodcrop", subtype = "Area") ## End(Not run)## Not run: a <- madrat::calcOutput("IndiaFoodcrop", subtype = "Area") ## End(Not run)
Calculates foodcrops data for India downloaded from: UPAg - Unified Portal for Agricultural Statistics by Department of Agriculture & Farmers Welfare https://upag.gov.in/dash-reports/stateprofile?rtab=State+Profile
calcIndiaStateFoodcrop(subtype = "Area")calcIndiaStateFoodcrop(subtype = "Area")
subtype |
Area, Yield, or Production |
magpie object containing Area, Yield, and Production data.
Ankit Saha
## Not run: a <- madrat::calcOutput("IndiaStateFoodcrop", subtype = "Area") ## End(Not run)## Not run: a <- madrat::calcOutput("IndiaStateFoodcrop", subtype = "Area") ## End(Not run)
Correct IndiaAPY data
correctIndiaAPY(x)correctIndiaAPY(x)
x |
magpie object provided by the read function |
magpie objects with corrected IndiaAPY data
Anastasis Giannousakis
## Not run: readSource("IndiaAPY", convert = "onlycorrect") ## End(Not run)## Not run: readSource("IndiaAPY", convert = "onlycorrect") ## End(Not run)
Correct IndiaStateAPY data
correctIndiaStateAPY(x)correctIndiaStateAPY(x)
x |
magpie object provided by the read function |
magpie objects with corrected IndiaStateAPY data
Ankit Saha
## Not run: readSource("IndiaStateAPY", convert = "onlycorrect") ## End(Not run)## Not run: readSource("IndiaStateAPY", convert = "onlycorrect") ## End(Not run)
Function to download data from https://eands.dacnet.nic.in/APY_96_To_07.htm. Best used in combination with the madrat package.
downloadIndiaAPY()downloadIndiaAPY()
Anastasis Giannousakis
## Not run: madrat::downloadSource(type="IndiaAPY")## Not run: madrat::downloadSource(type="IndiaAPY")
fullDATAINDIA Calculates foodcrops data for India taken from here: https://eands.dacnet.nic.in/APY_96_To_07.htm
fullDATAINDIA()fullDATAINDIA()
Foodcrop India data
Anastasis Giannousakis
## Not run: a <- retrieveData("DATAINDIA") ## End(Not run)## Not run: a <- retrieveData("DATAINDIA") ## End(Not run)
readIndiaAPY This function reads foodcrops data for India taken from here: https://eands.dacnet.nic.in/APY_96_To_07.htm
readIndiaAPY(subtype = NA)readIndiaAPY(subtype = NA)
subtype |
Area, Yield, or Production |
magpie object containing Area, Yield, and Production data.
Anastasis Giannousakis
## Not run: a <- madrat::readSource(type="IndiaAPY",subtype="Rice",convert="onlycorrect")## Not run: a <- madrat::readSource(type="IndiaAPY",subtype="Rice",convert="onlycorrect")
This function reads foodcrops data for India downloaded from: UPAg - Unified Portal for Agricultural Statistics by Department of Agriculture & Farmers Welfare https://upag.gov.in/dash-reports/stateprofile?rtab=State+Profile
readIndiaStateAPY()readIndiaStateAPY()
magpie object containing Area, Yield, and Production data.
Ankit Saha
## Not run: a <- madrat::readSource(type="IndiaStateAPY",subtype="Rice",convert="onlycorrect")## Not run: a <- madrat::readSource(type="IndiaStateAPY",subtype="Rice",convert="onlycorrect")